@@ -1,5 +1,6 @@
 import sys, argparse
 
+from omg import version
 from omg.cmd.use import use
 from omg.cmd.project import project, projects
 from omg.cmd.get_main import get_main
@@ -19,9 +20,10 @@ def main():
     subparsers = parser.add_subparsers()
 
     # omg use </path/to/must-gather>
-    p_use = subparsers.add_parser('use', parents=[common],
+    p_use = subparsers.add_parser('use',
                                   help='Select the must-gather to use')
-    p_use.add_argument('mg_path', metavar='</must/gather/location>', type=str)
+    p_use.add_argument('mg_path', metavar='</must/gather/location>', type=str, nargs='?')
+    p_use.add_argument('--cwd', dest="cwd", action='store_true')
     p_use.set_defaults(func=use)
 
     # omg project
@@ -62,6 +64,11 @@ def main():
                                   help='Display who you are')
     p_whoami.set_defaults(func=whoami)
 
+    # omg version
+    p_version = subparsers.add_parser('version', parents=[common],
+                                    help='Display omg version')
+    p_version.set_defaults(func=lambda x: print('omg version '+version+' (https://github.com/kxr/o-must-gather)'))
+
     # process args and call the corresponding function
     args = parser.parse_args()
     try:
