@@ -4,10 +4,10 @@ from omg.common.helper import age
 
 
 def pv_out(t, ns, res, output, show_type):
-    output_res=[[]]
+    output_res=[]
     # header
-    output_res[0].extend(['NAME','CAPACITY','ACCESS MODES','RECLAIM POLICY',
-                            'STATUS','CLAIM','STORAGECLASS','REASON','AGE'])
+    # we will append the header array at last after sorting
+    header = ['NAME','CAPACITY','ACCESS MODES','RECLAIM POLICY','STATUS','CLAIM','STORAGECLASS','REASON','AGE']
     # resources
     for r in res:
         p = r['res']
@@ -21,7 +21,12 @@ def pv_out(t, ns, res, output, show_type):
         row.append(p['spec']['capacity']['storage'])
         # access
         access = ",".join(p['spec']['accessModes'])
-        row.append(access)
+        if access == 'ReadWriteOnce':
+          row.append('RWO')
+        elif access == 'ReadOnlyMany':
+          row.append('ROX')
+        elif access == 'ReadWriteMany':
+          row.append('RWX')
         # reclaim
         row.append(p['spec']['persistentVolumeReclaimPolicy'])
         # status
@@ -52,4 +57,8 @@ def pv_out(t, ns, res, output, show_type):
 
         output_res.append(row)
 
-    print(tabulate(output_res,tablefmt="plain"))
+    # sort by 1st column
+    sorted_output = sorted(output_res)
+    sorted_output.insert(0,header)
+
+    print(tabulate(sorted_output,tablefmt="plain"))
